Research and contribution
===============================

Research
---------------

If you are doing research using the Hafnian library please reference this page and our `our paper <https://arxiv.org/abs/1805.12498>`_.

We are always open for collaboration, and can be contacted at research@xanadu.ai. 

Contribution
-------------

If you would like to get involved with the Machine Learning Toolbox, or you would like to contribute, simply fork our Github repository, and make a descriptive pull request.

- **Source Code:** https://github.com/XanaduAI/hafnian
- **Issue Tracker:** https://github.com/XanaduAI/hafnian/issues
   

Support
--------

If you are having issues, please let us know, either by email or by posting the issue on our Github issue tracker.

We have a mailing list located at: support@xanadu.ai
